# Sarkas
A Pure Python Molecular Dynamics package for Non-Ideal Plasmas

Sarkas aims at lowering the entry barrier for computational plasma physics by providing a comprehensive MD suite complete with pre- and post-processing tools commonly found in plasma physics.

Sarkas is entirely written in Python without calls to C/Fortran hence avoiding a two-language problem. It relies on the most common Python scientific packages, e.g. NumPy, Numba, SciPy, and Pandas, which provide a solid foundation built, optimized, and well documented by one of the largest community of developers. Furthermore, Sarkas is developed using an object-oriented approach allowing users to add new features in a straight-forward way.

Sarkas targets a broad user base: from experimentalists to computational physicists, from students approaching plasma physics for the first time to seasoned researchers. Therefore Sarkas’ design revolves around two primary requirements: ease-of-use and extensibility.

## Documentation
https://murillo-group.github.io/sarkas/

## Installation
Sarkas can be installed by running the command

    pip install sarkas
 
in a terminal or command prompt window.


